export const sketch = (container) => (p) => {
  // Measure the container
  const width = container.clientWidth;
  const height = container.clientHeight;

  // Extract p5 functions as local variables
  const createCanvas = p.createCanvas.bind(p);
  const background = p.background.bind(p);
  const noStroke = p.noStroke.bind(p);
  const noLoop = p.noLoop.bind(p);
  const fill = p.fill.bind(p);
  const ellipse = p.ellipse.bind(p);

  // You can copy-paste code from P5 examples,
  // just make sure to set `.parent(container)`
  // This one is from the P5 "Functions" example:
  // https://p5js.org/examples/structure-functions.html
  function setup() {
    createCanvas(width, height).parent(container);
    background(103);
    noStroke();
    noLoop();
  }

  function draw() {
    drawTarget(width * 0.25, height * 0.4, 282, 4);
    drawTarget(width * 0.5, height * 0.5, 431, 10);
    drawTarget(width * 0.75, height * 0.3, 150, 6);
  }

  function drawTarget(xloc, yloc, size, num) {
    const grayvalues = 255 / num;
    const steps = size / num;
    for (let i = 0; i < num; i++) {
      fill(i * grayvalues);
      ellipse(
        xloc,
        yloc,
        size - i * steps,
        size - i * steps,
      );
    }
  }

  // Attach our functions to the p5 instance.
  p.setup = setup;
  p.draw = draw;
};
